@@ -10,16 +10,16 @@ use warnings;
 use strict;
 
 package Curses::Toolkit::Widget::Window::Dialog;
-our $VERSION = '0.092920';
+our $VERSION = '0.093000';
 
 
 # ABSTRACT: a dialog window
 
 use parent qw(Curses::Toolkit::Widget::Window);
 
+1;
 
 
-__END__
 
 =pod
 
@@ -29,11 +29,15 @@ Curses::Toolkit::Widget::Window::Dialog - a dialog window
 
 =head1 VERSION
 
-version 0.092920
+version 0.093000
+
+=head1 SYNOPSIS
+
+    # FIXME: not yet implemented
 
 =head1 DESCRIPTION
 
-This widget is a dialog window
+This widget is a dialog window.
 
 
 
@@ -48,4 +52,8 @@ This software is copyright (c) 2008 by Damien "dams" Krotkine.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
\ No newline at end of file
+=cut 
+
+
+
+__END__
\ No newline at end of file
